.. currentmodule:: sardana.macroserver.macro

.. _sardana-macro-howto:

================
Writing macros
================


.. toctree::
    :maxdepth: 2
    
    General macro development <macros_general>
    Scan macro development <scan_framework>
    
